package com.mcwl.communityCenter.service.impl;

import cn.hutool.core.bean.BeanUtil;
import com.baomidou.mybatisplus.core.metadata.OrderItem;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.mcwl.common.constant.HttpStatus;
import com.mcwl.common.core.domain.AjaxResult;
import com.mcwl.common.core.domain.entity.SysUser;
import com.mcwl.common.core.page.TableDataInfo;
import com.mcwl.common.utils.SecurityUtils;
import com.mcwl.common.utils.StringUtils;
import com.mcwl.communityCenter.domain.Community;
import com.mcwl.communityCenter.domain.Question;
import com.mcwl.communityCenter.domain.QuestionComment;
import com.mcwl.communityCenter.domain.dto.*;
import com.mcwl.communityCenter.domain.vo.QuestionCommentVo;
import com.mcwl.communityCenter.domain.vo.QuestionVo;
import com.mcwl.communityCenter.mapper.*;
import com.mcwl.communityCenter.service.QuestionCommentService;
import com.mcwl.communityCenter.service.QuestionService;
import com.mcwl.system.service.ISysUserService;
import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.List;
import java.util.Objects;

@Service
@RequiredArgsConstructor
public class QuestionCommentServiceImpl extends ServiceImpl<QuestionCommentMapper, QuestionComment> implements QuestionCommentService {

    private final QuestionMapper questionMapper;

    @Override
    public AjaxResult comment(QuestionCommentRes questionCommentRes) {

        Long tenantId = questionCommentRes.getTenantId();
        Long communityId = questionCommentRes.getCommunityId();
        Long questionId = questionCommentRes.getQuestionId();

        Question question = questionMapper.selectByIdAndTenantIdAndCommunityId(questionId, tenantId, communityId);

        if (Objects.isNull(question)) {
            return AjaxResult.error("提问不存在");
        }

        QuestionComment questionComment = new QuestionComment();
        BeanUtil.copyProperties(questionCommentRes, questionComment);
        questionComment.setUserId(SecurityUtils.getUserId());

        baseMapper.insert(questionComment);


        return AjaxResult.success("评论成功");
    }



    @Override
    public TableDataInfo listByPage(QuestionCommentPageRes questionCommentPageRes) {

        Page<QuestionComment> page = initPage(questionCommentPageRes);

        baseMapper.selectByTenantIdAndCommunityIdAndQuestionIdPage(page, questionCommentPageRes.getTenantId(), questionCommentPageRes.getCommunityId(), questionCommentPageRes.getQuestionId());


        List<QuestionComment> questionCommentList = page.getRecords();
        List<QuestionCommentVo> questionCommentVoList = new ArrayList<>();
        for (QuestionComment questionComment : questionCommentList) {
            QuestionCommentVo questionCommentVo = new QuestionCommentVo();
            BeanUtil.copyProperties(questionComment, questionCommentVo);
            questionCommentVoList.add(questionCommentVo);
        }

        TableDataInfo tableDataInfo = new TableDataInfo();
        tableDataInfo.setCode(HttpStatus.SUCCESS);
        tableDataInfo.setMsg("查询成功");
        tableDataInfo.setRows(questionCommentVoList);
        tableDataInfo.setTotal(page.getTotal());

        return tableDataInfo;
    }

    @Override
    public AjaxResult adopt(QuestionCommentAdoptRes questionCommentAdoptRes) {

        Long tenantId = questionCommentAdoptRes.getTenantId();
        Long communityId = questionCommentAdoptRes.getCommunityId();
        Long questionId = questionCommentAdoptRes.getQuestionId();
        Long commentId = questionCommentAdoptRes.getCommentId();

//        QuestionComment questionComment = baseMapper.selectByIdAndTenantIdAndCommunityIdAndQuestionIdAndCommentId(commentId, tenantId, communityId, questionId);
        QuestionComment questionComment = null;
        if (Objects.isNull(questionComment)) {
            return AjaxResult.error("评论不存在");
        }

        if (questionComment.getIsAccept() == 1) {
            return AjaxResult.error("该评论已被采纳");
        }




        return AjaxResult.success();
    }


    private Page<QuestionComment> initPage(QuestionCommentPageRes questionCommentPageRes) {

        Page<QuestionComment> page = new Page<>(questionCommentPageRes.getPageNum(), questionCommentPageRes.getPageSize());

        if (StringUtils.isBlank(questionCommentPageRes.getOrderByColumn())) {
            questionCommentPageRes.setOrderByColumn("create_time");
        }

        boolean isAsc = Objects.equals(questionCommentPageRes.getIsAsc(), "asc");
        OrderItem orderItem = new OrderItem(questionCommentPageRes.getOrderByColumn(), isAsc);
        page.addOrder(orderItem);


        return page;
    }


}
